/*
 * Copyright 2011 Hanson Robokind LLC.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.robokind.api.speech;

import java.util.List;

/**
 * Contains a List of SpeechEvents and metadata about the event origin.
 * @author Matthew Stevenson <www.robokind.org>
 */
public interface SpeechEventList {
    /**
     * Returns the id String of the SpeechService the events originated from.
     * @return id String of the SpeechService the events originated from
     */
    public String getSpeechServiceId();
    /**
     * Returns the timestamp of the events.
     * @return timestamp of the events
     */
    public long getTimestampMillisecUTC();
    /**
     * Returns the List of SpeechEvents.
     * @return List of SpeechEvents
     */
    public List<SpeechEvent> getSpeechEvents();
}
