/*
 * Copyright 2011 Hanson Robokind LLC.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.robokind.api.speech.visemes;

import org.robokind.api.common.utils.Listener;
import org.robokind.api.speech.SpeechEvent;
import org.robokind.api.speech.SpeechEventList;

/**
 *
 * @author Matthew Stevenson <www.robokind.org>
 */
public class SpeechEventVisemeListener implements Listener<SpeechEventList>, VisemeListener{
    private VisemeListener myListener;
    
    public SpeechEventVisemeListener(VisemeListener visemeListener){
        if(visemeListener == null){
            throw new NullPointerException();
        }
        myListener = visemeListener;
    }
        
    @Override
    public void handleEvent(SpeechEventList event) {
        if(event == null){
            return;
        }
        for(SpeechEvent se : event.getSpeechEvents()){
            if(se.getSpeechEventType().equals("VISEME")){
                handleVisemeEvent(new DefaultVisemeEvent(
                        event.getSpeechServiceId(), se, 
                        event.getTimestampMillisecUTC()));
            }
        }
    }

    @Override
    public void handleVisemeEvent(VisemeEvent event) {
        myListener.handleVisemeEvent(event);
    }
    
}
