/*
 * Copyright 2011 Hanson Robokind LLC.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.robokind.impl.motion.pololu;

import org.robokind.api.motion.servos.ServoController;
import org.robokind.api.common.config.VersionProperty;
import org.robokind.api.common.services.ServiceFactory;

/**
 * Connector to a Pololu Mini-Maestro servo control board.
 * 
 * @author Matthew Stevenson <www.robokind.org>
 */
public class MaestroConnector implements ServiceFactory<ServoController,MaestroControllerConfig>{

    @Override
    public ServoController build(MaestroControllerConfig config) {
        return new MaestroController(config);
    }

    @Override
    public VersionProperty getServiceVersion() {
        return MaestroController.VERSION;
    }
    
    @Override
    public Class<MaestroControllerConfig> getServiceConfigurationClass() {
        return MaestroControllerConfig.class;
    }

    @Override
    public Class<ServoController> getServiceClass() {
        return ServoController.class;
    }
}
