/*
 * Copyright 2011 Hanson Robokind LLC.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.robokind.impl.speech;

import java.net.URISyntaxException;
import javax.jms.Connection;
import javax.jms.ConnectionFactory;
import javax.jms.Destination;
import javax.jms.JMSException;
import javax.jms.Session;
import org.apache.qpid.client.AMQConnectionFactory;
import org.apache.qpid.client.AMQQueue;
import org.osgi.framework.BundleContext;

/**
 *
 * @author Matthew Stevenson <www.robokind.org>
 */
public class Launcher {
    /**
     * Creates and starts a JMSSpeechService.
     * @param context
     * @param conStr
     * @param cmd
     * @param err
     * @param speech
     * @param event
     * @return
     * @throws JMSException
     * @throws URISyntaxException
     * @throws Exception 
     */
    public static JMSSpeechService startServiceFrame(
            BundleContext context,
            String conStr, 
            String cmd, String err,
            String speech, String event) throws JMSException, URISyntaxException, Exception
    {        
        ConnectionFactory cf = new AMQConnectionFactory(conStr);
        Connection connection = cf.createConnection();
        Destination reqDest = new AMQQueue(speech);
        Destination eventDest = new AMQQueue(event);
        connection.start();
        Session session = 
                connection.createSession(false, Session.CLIENT_ACKNOWLEDGE);
        Destination cmdDest = new AMQQueue(cmd);
        Destination errDest = new AMQQueue(err);
        
        JMSSpeechService service = new JMSSpeechService(
                session, cmdDest, errDest, reqDest, eventDest);
        return service;
    }
}
