/*
 * Copyright 2011 Hanson Robokind LLC.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.robokind.impl.speech;

import org.robokind.api.common.utils.Adapter;
import org.robokind.api.speech.SpeechEvent;
import org.robokind.avrogen.speech.SpeechEventRecord;

/**
 * SpeechEvent implementation wrapping a SpeechEventRecord.
 * @author Matthew Stevenson <www.robokind.org>
 */
public class PortableSpeechEvent implements SpeechEvent {
    
    private SpeechEventRecord mySpeechEvent;
    
    /**
     * Creates a new SpeechEvent from the given SpeechEventRecord.
     * @param event SpeechEventRecord to wrap
     */
    public PortableSpeechEvent(SpeechEventRecord event){
        if(event == null){
            throw new NullPointerException();
        }
        mySpeechEvent = event;
    }

    @Override
    public String getSpeechEventType() {
        return mySpeechEvent.eventType.toString();
    }

    @Override
    public Long getStreamNumber() {
        return mySpeechEvent.streamNumber;
    }

    @Override
    public Integer getTextPosition() {
        return mySpeechEvent.textPosition;
    }

    @Override
    public Integer getTextLength() {
        return mySpeechEvent.textLength;
    }

    @Override
    public Integer getCurrentData() {
        return mySpeechEvent.currentData;
    }

    @Override
    public Integer getNextData() {
        return mySpeechEvent.nextData;
    }

    @Override
    public String getStringData() {
        return mySpeechEvent.stringData.toString();
    }

    @Override
    public Integer getDuration() {
        return mySpeechEvent.duration;
    }
    
    /**
     * Converts a SpeechEventRecord to a PortableSpeechEvent.
     */
    public static class RemoteSpeechEventAdapter 
            implements Adapter<SpeechEventRecord, SpeechEvent>{

        @Override
        public SpeechEvent adapt(SpeechEventRecord a) {
            return new PortableSpeechEvent(a);
        }
        
    }
}
