/*
 * Copyright 2011 Hanson Robokind LLC.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.robokind.integration.animation_motion;

import java.util.HashMap;
import java.util.Map;
import java.util.Map.Entry;
import org.osgi.framework.BundleContext;
import org.robokind.api.animation.utils.ChannelsParameterSource;
import org.robokind.api.common.position.NormalizedDouble;
import org.robokind.api.motion.Robot;
import org.robokind.api.motion.Robot.JointId;
import org.robokind.api.motion.Robot.RobotPositionMap;
import org.robokind.api.motion.Joint;
import org.robokind.api.motion.utils.RobotUtils;

/**
 *
 * @author Matthew Stevenson <www.robokind.org>
 */
public class ChannelRobotParameters implements ChannelsParameterSource{
    private BundleContext myContext;
    private Robot.Id myRobotId;
    
    public ChannelRobotParameters(BundleContext context, Robot.Id robotId){
        if(context == null || robotId == null){
            throw new NullPointerException();
        }
        myContext = context;
        myRobotId = robotId;
    }
    
    @Override
    public Map<Integer, String> getChannelNames() {
        Map<JointId,String> nameMap = 
                RobotUtils.getJointNames(myContext, myRobotId);
        if(nameMap == null){
            return null;
        }
        Map<Integer, String> names = new HashMap(nameMap.size());
        for(Entry<JointId,String> e : nameMap.entrySet()){
            JointId djId = e.getKey();
            String name = e.getValue();
            if(djId == null || name == null){
                continue;
            }
            Joint.Id jId = djId.getJointId();
            Integer id = jId.getLogicalJointNumber();
            names.put(id, name);
        }
        return names;
    }

    @Override
    public String getChannelName(int id) {
        Map<Integer,String> map = getChannelNames();
        return map == null ? null : map.get(id);
    }

    @Override
    public Map<Integer,Double> getDefaultPositions() {
        RobotPositionMap posMap = 
                RobotUtils.getDefaultPositions(myContext, myRobotId);
        if(posMap == null){
            return null;
        }
        Map<Integer, Double> pos = new HashMap(posMap.size());
        for(Entry<JointId,NormalizedDouble> e : posMap.entrySet()){
            JointId djId = e.getKey();
            NormalizedDouble val = e.getValue();
            if(djId == null || val == null){
                continue;
            }
            Joint.Id jId = djId.getJointId();
            Integer id = jId.getLogicalJointNumber();
            pos.put(id, val.getValue());
        }
        return pos;
    }

    @Override
    public Double getDefaultPosition(int id) {
        RobotPositionMap posMap = 
                RobotUtils.getDefaultPositions(myContext, myRobotId);
        if(posMap == null){
            return null;
        }
        Joint.Id jId = new Joint.Id(id);
        Robot.JointId djId = new JointId(myRobotId, jId);
        NormalizedDouble pos = posMap.get(djId);
        return pos == null ? null : pos.getValue();
    }
}
